# Styles for from2to

This directory contains CSS styles shared by all converters (e.g., md2pdf2, md2html2).

- `included/`: CSS files packaged with from2to.
- `cache/`: Download cache for CSS fetched from URLs via the `-s/--style` option.

To refresh or add more styles to `included/`, see scripts in `scripts/`.
